pub fn get_projectile_shape(
caliber: f64,
weight_grains: f64,
g_model: &str,
) -> ProjectileShapeExpand description
Estimate projectile shape from physical parameters
This is a simple heuristic based on typical bullet designs.
pub fn get_projectile_shape(
caliber: f64,
weight_grains: f64,
g_model: &str,
) -> ProjectileShapeEstimate projectile shape from physical parameters
This is a simple heuristic based on typical bullet designs.